@@ -364,7 +364,7 @@ U_expected <- structure(c(0L, 0L, 0L, 0L, 0L, 0L, 1L, 0L, 0L, 0L, 0L, 0L,
 result <- run(model)
 stopifnot(identical(model@G, result@G))
 stopifnot(identical(model@S, result@S))
-stopifnot(identical(trajectory(result, as.is = TRUE), U_expected))
+stopifnot(identical(trajectory(result, format = "matrix"), U_expected))
 stopifnot(identical(model@ldata, result@ldata))
 stopifnot(identical(model@tspan, result@tspan))
 stopifnot(identical(model@u0, result@u0))
@@ -376,7 +376,7 @@ if (SimInf:::have_openmp()) {
     set_num_threads(1)
     stopifnot(identical(model@G, result_omp@G))
     stopifnot(identical(model@S, result_omp@S))
-    stopifnot(identical(trajectory(result_omp, as.is = TRUE), U_expected))
+    stopifnot(identical(trajectory(result_omp, format = "matrix"), U_expected))
     stopifnot(identical(model@ldata, result_omp@ldata))
     stopifnot(identical(model@tspan, result_omp@tspan))
     stopifnot(identical(model@u0, result_omp@u0))
@@ -436,7 +436,7 @@ U_expected <- structure(c(0L, 0L, 0L, 0L, 0L, 0L, 1L, 0L, 0L, 0L, 0L, 0L,
 result <- run(model)
 stopifnot(identical(model@G, result@G))
 stopifnot(identical(model@S, result@S))
-stopifnot(identical(trajectory(result, as.is = TRUE), U_expected))
+stopifnot(identical(trajectory(result, format = "matrix"), U_expected))
 stopifnot(identical(model@ldata, result@ldata))
 stopifnot(identical(model@tspan, result@tspan))
 stopifnot(identical(model@u0, result@u0))
@@ -448,7 +448,7 @@ if (SimInf:::have_openmp()) {
     set_num_threads(1)
     stopifnot(identical(model@G, result_omp@G))
     stopifnot(identical(model@S, result_omp@S))
-    stopifnot(identical(trajectory(result_omp, as.is = TRUE), U_expected))
+    stopifnot(identical(trajectory(result_omp, format = "matrix"), U_expected))
     stopifnot(identical(model@ldata, result_omp@ldata))
     stopifnot(identical(model@tspan, result_omp@tspan))
     stopifnot(identical(model@u0, result_omp@u0))
@@ -508,7 +508,7 @@ U_expected <- structure(c(0L, 0L, 0L, 0L, 0L, 0L, 2L, 0L, 0L, 0L, 0L, 0L,
 result <- run(model)
 stopifnot(identical(model@G, result@G))
 stopifnot(identical(model@S, result@S))
-stopifnot(identical(trajectory(result, as.is = TRUE), U_expected))
+stopifnot(identical(trajectory(result, format = "matrix"), U_expected))
 stopifnot(identical(model@ldata, result@ldata))
 stopifnot(identical(model@tspan, result@tspan))
 stopifnot(identical(model@u0, result@u0))
@@ -520,7 +520,7 @@ if (SimInf:::have_openmp()) {
     set_num_threads(1)
     stopifnot(identical(model@G, result_omp@G))
     stopifnot(identical(model@S, result_omp@S))
-    stopifnot(identical(trajectory(result_omp, as.is = TRUE), U_expected))
+    stopifnot(identical(trajectory(result_omp, format = "matrix"), U_expected))
     stopifnot(identical(model@ldata, result_omp@ldata))
     stopifnot(identical(model@tspan, result_omp@tspan))
     stopifnot(identical(model@u0, result_omp@u0))
@@ -582,7 +582,7 @@ set.seed(1)
 result <- run(model)
 stopifnot(identical(model@G, result@G))
 stopifnot(identical(model@S, result@S))
-stopifnot(identical(trajectory(result, as.is = TRUE), U_expected))
+stopifnot(identical(trajectory(result, format = "matrix"), U_expected))
 stopifnot(identical(model@ldata, result@ldata))
 stopifnot(identical(model@tspan, result@tspan))
 stopifnot(identical(model@u0, result@u0))
@@ -595,7 +595,7 @@ if (SimInf:::have_openmp()) {
     set_num_threads(1)
     stopifnot(identical(model@G, result_omp@G))
     stopifnot(identical(model@S, result_omp@S))
-    stopifnot(identical(trajectory(result_omp, as.is = TRUE), U_expected))
+    stopifnot(identical(trajectory(result_omp, format = "matrix"), U_expected))
     stopifnot(identical(model@ldata, result_omp@ldata))
     stopifnot(identical(model@tspan, result_omp@tspan))
     stopifnot(identical(model@u0, result_omp@u0))
@@ -724,7 +724,7 @@ S_expected <- c(0, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3)
 
 res <- run(model)
 S_observed <- colSums(trajectory(res, compartments = c("S_1", "S_2", "S_3"),
-                                 node = 1, as.is = TRUE))
+                                 index = 1, format = "matrix"))
 stopifnot(identical(S_observed, S_expected))
 
 if (SimInf:::have_openmp()) {
@@ -732,7 +732,7 @@ if (SimInf:::have_openmp()) {
     res <- run(model)
     set_num_threads(1)
     S_observed <- colSums(trajectory(res, compartments = c("S_1", "S_2", "S_3"),
-                                     node = 1, as.is = TRUE))
+                                     index = 1, format = "matrix"))
     stopifnot(identical(S_observed, S_expected))
 }
 
