@@ -149,8 +149,7 @@ if (SimInf:::have_openmp()) {
         20L))
 
     p <- prevalence(result, I ~ S + I, format = "matrix")
-    stopifnot(identical(length(p), 10L))
-    stopifnot(is.null(dim(p)))
+    stopifnot(identical(dim(p), c(1L, 10L)))
 
     p <- prevalence(result, I ~ S + I, level = 3, format = "matrix")
     stopifnot(identical(dim(p), c(2L, 10L)))
